@@ -22,7 +22,7 @@ copyright = '2020-2024, The Joalla Team'
 author = 'The Joalla Team'
 
 # The full version, including alpha/beta/rc tags
-release = '2.7.1'
+release = '2.8'
 
 
 # -- General configuration ---------------------------------------------------
@@ -80,7 +80,8 @@ html_css_files = ["p3dc.css"]
 # MyST extenstion configuration
 myst_heading_anchors = 7
 myst_enable_extensions = [
-    "substitution"
+    "substitution",
+    "colon_fence",
 ]
 myst_substitutions = {
   "class": "I'm a **substitution**"
